@@ -1,10 +1,11 @@
-use std::collections::HashSet;
 use std::sync::atomic::{AtomicBool, Ordering};
 use std::sync::{Arc, OnceLock};
+use std::time::Duration;
 
+use dashmap::DashMap;
 use indexmap::IndexSet;
 use itertools::Itertools;
-use pkgcraft::repo::ebuild::EbuildRepo;
+use pkgcraft::repo::EbuildRepo;
 use pkgcraft::restrict::{Restrict, Scope, TryIntoRestrict};
 use pkgcraft::utils::bounded_jobs;
 use tracing::{info, warn};
@@ -17,7 +18,7 @@ use crate::report::{Report, ReportKind, ReportSet, ReportTarget};
 use crate::source::PkgFilter;
 
 /// Scanner builder.
-#[derive(Debug, Default)]
+#[derive(Debug, Default, Clone)]
 pub struct Scanner {
     jobs: usize,
     force: bool,
@@ -26,6 +27,7 @@ pub struct Scanner {
     exit: IndexSet<ReportSet>,
     filters: IndexSet<PkgFilter>,
     failed: Arc<AtomicBool>,
+    stats: Arc<DashMap<Check, Duration>>,
 }
 
 impl Scanner {
@@ -89,6 +91,11 @@ impl Scanner {
         self.failed.load(Ordering::Relaxed)
     }
 
+    /// Return the check timing statistics for the scanner.
+    pub fn stats(&self) -> &Arc<DashMap<Check, Duration>> {
+        &self.stats
+    }
+
     /// Run the scanner returning an iterator of reports.
     pub fn run<T>(&self, repo: &EbuildRepo, value: T) -> crate::Result<ReportIter>
     where
@@ -129,11 +136,11 @@ impl Scanner {
                 }
             })
             .filter(|result| {
-                if let Err(Error::ReportInit(report, msg)) = &result {
-                    if !selected.contains(report) {
-                        warn!("skipping {report} report: {msg}");
-                        return false;
-                    }
+                if let Err(Error::ReportInit(report, msg)) = &result
+                    && !selected.contains(report)
+                {
+                    warn!("skipping {report} report: {msg}");
+                    return false;
                 }
                 true
             })
@@ -156,11 +163,11 @@ impl Scanner {
                 }
             })
             .filter(|result| {
-                if let Err(Error::CheckInit(check, msg)) = &result {
-                    if !selected.contains(check) {
-                        warn!("skipping {check} check: {msg}");
-                        return false;
-                    }
+                if let Err(Error::CheckInit(check, msg)) = &result
+                    && !selected.contains(check)
+                {
+                    warn!("skipping {check} check: {msg}");
+                    return false;
                 }
                 true
             })
@@ -180,11 +187,12 @@ pub(crate) struct ScannerRun {
     pub(crate) filters: IndexSet<PkgFilter>,
     pub(crate) checks: IndexSet<Check>,
     pub(crate) ignore: Ignore,
-    enabled: HashSet<ReportKind>,
-    exit: HashSet<ReportKind>,
+    enabled: IndexSet<ReportKind>,
+    exit: IndexSet<ReportKind>,
     failed: Arc<AtomicBool>,
     pub(crate) sort: bool,
     pub(crate) sender: OnceLock<ReportSender>,
+    pub(crate) stats: Arc<DashMap<Check, Duration>>,
 }
 
 impl ScannerRun {
@@ -214,6 +222,7 @@ impl ScannerRun {
             failed: scanner.failed.clone(),
             sort: scanner.sort,
             sender: Default::default(),
+            stats: scanner.stats.clone(),
         })
     }
 
@@ -235,10 +244,13 @@ impl ScannerRun {
                 || kind == ReportKind::IgnoreInvalid
                 || !self.ignore.ignored(&report, self))
         {
-            if self.exit.contains(&kind) {
-                self.failed.store(true, Ordering::Relaxed);
+            // skip reports with scopes above the current scan scope
+            if report.scope() <= &self.scope {
+                if self.exit.contains(&kind) {
+                    self.failed.store(true, Ordering::Relaxed);
+                }
+                self.sender().report(report);
             }
-            self.sender().report(report);
         }
     }
 
